@@ -41,7 +41,7 @@ def get_git_hash(rev='HEAD'):
     git_hash = ''
     try:
         git_out = subprocess.check_output(['git', 'rev-parse', rev], universal_newlines=True)
-    except subprocess.CalledProcessError as e:
+    except subprocess.CalledProcessError:
         mylogger.exception("Couldn't determine the git hash!")
     else:
         git_hash = git_out.strip()
